'''Application settings for django-autoconfig.'''

from django.conf import settings

#: Extra URLs for autourlconf
AUTOCONFIG_EXTRA_URLS = getattr(settings, 'AUTOCONFIG_EXTRA_URLS', ())

#: A view name (suitable for reverse()) that the base / will redirect to.
AUTOCONFIG_INDEX_VIEW = getattr(settings, 'AUTOCONFIG_INDEX_VIEW', None)



'''Pull settings from environment variables.'''

import ast
import logging
import os

LOGGER = logging.getLogger(__name__)


def get_settings_from_environment(environ):
    '''Deduce settings from environment variables'''
    settings = {}
    for name, value in environ.items():
        if not name.startswith('DJANGO_'):
            continue
        name = name.replace('DJANGO_', '', 1)
        try:
            settings[name] = ast.literal_eval(value)
        except (SyntaxError, ValueError) as err:
            LOGGER.warn("Unable to parse setting %s=%s (%s)", name, value, err)
    return settings

SETTINGS = get_settings_from_environment(os.environ)



'''Setup file for django-autoconfig.'''
from setuptools import setup, find_packages
from django_autoconfig.version import __VERSION__

import sys

INSTALL_REQUIRES = [
    'django < 1.9',
]

if sys.version_info < (2, 7):
    INSTALL_REQUIRES.append('importlib')

setup(
    name='django-autoconfig',
    version=__VERSION__,
    packages=find_packages(),
    description='Automatic configuration of Django projects based on the application requirements.',
    long_description=open('README.rst').read(),
    author='Mike Bryant',
    author_email='mike@mikebryant.me.uk',
    install_requires=INSTALL_REQUIRES,
    include_package_data=True,
    test_suite           = 'setuptest.setuptest.SetupTestSuite',
    tests_require        = ['django-setuptest>=0.2'],
    url='https://github.com/mikebryant/django-autoconfig',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Framework :: Django',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
    ],
)
